@@ -37,7 +37,7 @@ no warnings;
 
 @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.41._0'; # our $VERSION = '';
+$VERSION = '0.43.0'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -99,6 +99,7 @@ sub descend
 	@base_columns = @main::base_columns;
 	@maketabledata = @main::maketabledata;
 	@filter_columns = @main::filter_columns;
+	%vals = %main::vals;
 	
 	my @simcases = @{ $dirfiles{simcases} }; #say "dump(\@simcases): " . dump(@simcases);
 	my @simstruct = @{ $dirfiles{simstruct} }; #say "dump(\@simstruct): " . dump(@simstruct);
@@ -123,6 +124,10 @@ sub descend
 	my $repblock = $dirfiles{repblock};
 	my $descendlist = $dirfiles{descendlist};
 	my $descendblock = $dirfiles{descendblock};
+	
+	my $skipfile = $vals{skipfile}; say TOSHELL "dump(\$skipfile): " . dump($skipfile);
+	my $skipsim = $vals{skipsim}; say TOSHELL "dump(\$skipsim): " . dump($skipsim);
+	my $skipreport = $vals{skipreport}; say TOSHELL "dump(\$skipreport): " . dump($skipreport);
 		
 	#my $getpars = shift;
 	#eval( $getpars );
@@ -146,6 +151,8 @@ sub descend
 	my @uplift = @{ $d{uplift} }; #say TOSHELL "dump(\@uplift): " . dump(@uplift);
 	#eval($getparshere);
 	
+	my $skip = $vals{$countvar}{skip}; say TOSHELL "dumpinreport(\$skip): " . dump($skip);
+	
 	my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOSHELL "dump(\$rootname): " . dump($rootname);
 	my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOSHELL "dumpIN( \@blockelts) " . dump(@blockelts);
 	my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOSHELL "dumpIN( \@blocks) " . dump(@blocks);
