@@ -42,7 +42,7 @@ no warnings;
 
 @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.41._0'; # our $VERSION = '';
+$VERSION = '0.43.0'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -110,6 +110,7 @@ sub sim    # This function launch the simulations in ESP-r
 	@base_columns = @main::base_columns;
 	@maketabledata = @main::maketabledata;
 	@filter_columns = @main::filter_columns;
+	%vals = %main::vals;
 	
 	my @simcases = @{ $dirfiles{simcases} }; #say "dump(\@simcases): " . dump(@simcases);
 	my @simstruct = @{ $dirfiles{simstruct} }; #say "dump(\@simstruct): " . dump(@simstruct);
@@ -135,13 +136,18 @@ sub sim    # This function launch the simulations in ESP-r
 	my $descendlist = $dirfiles{descendlist};
 	my $descendblock = $dirfiles{descendblock};
 	
+	my $skipfile = $vals{skipfile}; say TOSHELL "dump(\$skipfile): " . dump($skipfile);
+	my $skipsim = $vals{skipsim}; say TOSHELL "dump(\$skipsim): " . dump($skipsim);
+	my $skipreport = $vals{skipreport}; say TOSHELL "dump(\$skipreport): " . dump($skipreport);
+	
 	#my $getpars = shift;
 	#eval( $getpars );
 
 	#if ( fileno (MORPHLIST) 
 
 	my @container;
-
+	
+	my $countinstance = 0;
 	foreach my $instance (@instances)
 	{
 		my %d = %{$instance};
@@ -156,6 +162,8 @@ sub sim    # This function launch the simulations in ESP-r
 		my @uplift = @{ $d{uplift} }; #say TOSHELL "dump(\@uplift): " . dump(@uplift);
 		#eval($getparshere);
 		
+		my $skip = $vals{$countvar}{skip}; say TOSHELL "dumpinsim(\$skip): " . dump($skip);
+		
 		my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOSHELL "dump(\$rootname): " . dump($rootname);
 		my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOSHELL "dumpIN( \@blockelts) " . dump(@blockelts);
 		my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOSHELL "dumpIN( \@blocks) " . dump(@blocks);
@@ -183,75 +191,81 @@ sub sim    # This function launch the simulations in ESP-r
 		#}
 
 		my $simelt = $to;
-		my $countsim = 0;
-		foreach my $date_to_sim (@simtitles)
+		if ( not ( eval ( $skipsim )))
 		{
-			my $simdataref = $simdata[$countsim];
-			my @simdata = @{$simdataref};
-			my $resfile = "$simelt-$date_to_sim.res";
-			my $flfile = "$simelt-$date_to_sim.fl";
-			push (@ress, $resfile); # ERASE
-			push (@flfs, $flfile); # ERASE
 			
-			#if ( fileno (SIMLIST) )
-			#if (not (-e $simlist ) )
-			#{
-			#	if ( $countblock == 0 )
-			#	{
-					open( SIMLIST, ">>$simlist") or die;
-			#	}
-			#	else 
-			#	{
-			#		open( SIMLIST, ">>$simlist") or die;
-			#	}
-			#}
-			
-			#if ( fileno (SIMBLOCK) )
-			if (not (-e $simblock ) )
+			my $countsim = 0;
+			foreach my $date_to_sim ( @simtitles )
 			{
-				if ( $countblock == 0 )
+				my @simdat = @{ $simdata[ $countsim ] }; say TOSHELL "dump(\@simdat): " . dump(@simdat); 
+				my $begin = $simdat[0]; say TOSHELL "dump(\$begin): " . dump($begin); 
+				my $end = $simdat[1]; say TOSHELL "dump(\$end): " . dump($end); 
+				my $before = $simdat[2]; say TOSHELL "dump(\$before): " . dump($before); 
+				my $step = $simdat[3]; say TOSHELL "dump(\$step): " . dump($step); 
+				my $resfile = "$simelt-$date_to_sim.res";
+				my $flfile = "$simelt-$date_to_sim.fl";
+				push (@ress, $resfile); # ERASE
+				push (@flfs, $flfile); # ERASE
+				
+				#if ( fileno (SIMLIST) )
+				#if (not (-e $simlist ) )
+				#{
+				#	if ( $countblock == 0 )
+				#	{
+						open( SIMLIST, ">>$simlist") or die;
+				#	}
+				#	else 
+				#	{
+				#		open( SIMLIST, ">>$simlist") or die;
+				#	}
+				#}
+				
+				#if ( fileno (SIMBLOCK) )
+				if (not (-e $simblock ) )
 				{
-					open( SIMBLOCK, ">>$simblock"); # or die;
-				}
-				else 
-				{
-					open( SIMBLOCK, ">>$simblock"); # or die;
-				}
-			}
-			
-			#say "INSIM1\$countcase : " . dump($countcase);
-			#say "INSIM1\@rootnames : " . dump(@rootnames);
-			#say "INSIM1\$countblock : " . dump($countblock);
-			#say "INSIM1\@sweeps : " . dump(@sweeps);
-			#say "INSIM1\@varinumbers : " . dump(@varinumbers);
-			#say "INSIM1\@miditers : " . dump(@miditers);
-			#say "INSIM1\@winneritems : " . dump(@winneritems);
-			#say "INSIM1\@morphcases : " . dump(@morphcases);
-			#say "INSIM1\@morphstruct : " . dump(@morphstruct);
-		
-			push ( @{ $simstruct[$countcase][$countblock] }, $resfile );
-			print SIMBLOCK "$resfile\n";
-			
-			if ( ( not ( $resfile ~~ @simcases ) ) and ( not ( -e $resfile ) ) )
-			{
-				push ( @simcases, $resfile );
-				print SIMLIST "$resfile\n";
-					
-				unless ( $preventsim eq "y" )
-				{
-					if ( $simnetwork eq "y" )
+					if ( $countblock == 0 )
 					{
-						say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $resfile and $flfile. " ;
-						my $printthis =	
+						open( SIMBLOCK, ">>$simblock"); # or die;
+					}
+					else 
+					{
+						open( SIMBLOCK, ">>$simblock"); # or die;
+					}
+				}
+				
+				#say "INSIM1\$countcase : " . dump($countcase);
+				#say "INSIM1\@rootnames : " . dump(@rootnames);
+				#say "INSIM1\$countblock : " . dump($countblock);
+				#say "INSIM1\@sweeps : " . dump(@sweeps);
+				#say "INSIM1\@varinumbers : " . dump(@varinumbers);
+				#say "INSIM1\@miditers : " . dump(@miditers);
+				#say "INSIM1\@winneritems : " . dump(@winneritems);
+				#say "INSIM1\@morphcases : " . dump(@morphcases);
+				#say "INSIM1\@morphstruct : " . dump(@morphstruct);
+				
+				push ( @{ $simstruct[ $countcase ][ $countblock ][ $countinstance ] }, $resfile );
+				print SIMBLOCK "$resfile\n";
+			
+				if ( ( not ( $resfile ~~ @simcases ) ) and ( not ( -e $resfile ) ) )
+				{
+					push ( @simcases, $resfile );
+					print SIMLIST "$resfile\n";
+						
+					unless ( $preventsim eq "y" )
+					{
+						if ( $simnetwork eq "y" )
+						{
+							say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $resfile and $flfile. " ;
+							my $printthis =	
 "bps -file $simelt/cfg/$fileconfig -mode script<<XXX
 
 c
 $resfile
 $flfile
-$simdata[0 + (4*$countsim)]
-$simdata[1 + (4*$countsim)]
-$simdata[2 + (4*$countsim)]
-$simdata[3 + (4*$countsim)]
+$begin
+$end
+$before
+$step
 s
 $simnetwork
 Results for $simelt-$dates_to_sim
@@ -266,28 +280,28 @@ y
 -
 XXX
 ";
-						if ($exeonfiles eq "y") 
+							if ($exeonfiles eq "y") 
+							{
+								print `$printthis`;
+							}
+							print TOSHELL " 	
+	#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.\
+	$printthis
+	\n";
+							print OUTFILE "TWO, $resfile\n";
+						}	
+						else # THAT IS: if ( $simnetwork eq "n" )
 						{
-							print `$printthis`;
-						}
-						print TOSHELL " 	
-#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance.\
-$printthis
-\n";
-						print OUTFILE "TWO, $resfile\n";
-					}	
-					else # THAT IS: if ( $simnetwork eq "n" )
-					{
-						say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $resfile. " ;
-						my $printthis =
+							say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $resfile. " ;
+							my $printthis =
 "bps -file $simelt/cfg/$fileconfig -mode script<<XXX
 
 c
 $resfile
-$simdata[0 + (4*$countsim)]
-$simdata[1 + (4*$countsim)]
-$simdata[2 + (4*$countsim)]
-$simdata[3 + (4*$countsim)]
+$begin
+$end
+$before
+$step
 s
 $simnetwork
 Results for $simelt-$date_to_sim
@@ -302,19 +316,21 @@ y
 -
 XXX
 ";
-						if ($exeonfiles eq "y") 
-						{
-							print `$printthis`;
-						}
-						print TOSHELL "  
-$printthis
-";
-					}					
-				}		
+							if ($exeonfiles eq "y") 
+							{
+								print `$printthis`;
+							}
+							print TOSHELL "  
+	$printthis
+	";
+						}					
+					}		
+				}
+				$countsim++;
 			}
-			$countsim++;
+		
 		}
-		$countdir++;
+		$countinstance++;
 	}
 	close SIMLIST;
 	close SIMBLOCK;
