@@ -8,7 +8,9 @@
 
 $mypath = "/home/luca/modtest" ;# path of the directory in which you are going to work
 
-@sweeps = ( [ [ 1, 2 ] ] );
+@sweeps = ( [ [ 1 ] ] );
+#@sweeps = ( [ [ 1, 2, 3, 4 ] ] );
+#@sweeps = ( [ [ 1, 2, 3], [2, 3, 4] , [ 3, 4, 5], [4, 5, 6 ] ] );
 #@sweeps = ( [ [ 1, 2, 3, 4, 5, 6, 7, 8 ] ] );
 # OR: ( [ [1, 2], [2, 3] ] ); # OR: @sweeps = ( [ [1, 2, 3, 4], [3, 4, 5, 1], [5, 1, 2, 3] ], [ [1, 2], [2, 3] ] ); # OR: @sweeps = ( [ [1, 2, 3, 4], [3, 4, 5, 1], [5, 1, 2, 3] ] );
 # DESCRIPTION OF A (MAYBE OVERLAPPING) COORDINATE BLOCK DESCENT. # THE NUMBERS ARE THE VARIABLE NUMBERS.
@@ -18,13 +20,18 @@ $mypath = "/home/luca/modtest" ;# path of the directory in which you are going t
 # @sweeps IS NOT OVERRIDDEN ON THE BASIS OF WHAT IS SPECIFIED IN @chanceseed AND @caseseed. 
 # IT HAS TO BE UNSPECIFIED IF THE SEARCH STRUCTURE HAS TO BE CALCULATE BY THE PROGRAM. @sweepseed MAY BE SPECIFIED IN ITS PLACE.
 
-@varinumbers = ( { 1 => 2, 2 => 2 } );
+@varinumbers = ( { 1 => 3 } );
+#@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
+#@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3, 5 => 3, 6 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 #@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 9, 7 => 2, 8 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.
 
-@mediumiters = ( { 1 => 2, 2 => 2 } );
-#@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 1, 6 => 5, 7 => 1 , 8 => 1 } );mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 1, 6 => 5, 7 => 1 , 8 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
+@mediumiters = ( { 1 => 2 } );
+#@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2 } );
+#@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 2 } );
+#@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 1, 6 => 5, 7 => 1 , 8 => 1 } );
+#mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 1, 6 => 5, 7 => 1 , 8 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 # IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 
 
@@ -46,22 +53,25 @@ $fileconfig = "boxform.cfg"; # name of the configuration file of the model, whic
 
 $simnetwork = "n"; # is there a mass/flow network? This information regards the simulation settings.
 $exeonfiles = "y";
-$preventsim eq "y";
+$preventsim = "n";
 
 @simtitles = 
 ( 
-"feb01-feb07" , "jul01-jul07"
+"feb01-feb08" , "jul01-jul08"
 );
 # OR: ("mar1-apr30", "mar1-apr30" ); 
 # write here the name of the time periods will be taken into account in the simulations.
 # This will decide the name of the simulation files. Short names are better.
 
+#$vals{skipsim} = " ( ( $to =~ /_1-2/ ) or ( $to =~ /_2-2/ ) or ( $to =~ /_3-2/ ) or ( $to =~ /_4-2/ ) or ( $to =~ /_5-2/ ) or ( $to =~ /_6-2/ ) ) ";
+#$vals{skipsim} = " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-3/ ) or ( \$to =~ /_6-5/ ) ) ";
+
 @simdata = 
 ( [ 
-"1 2", "7 2", "20", "1" 
+"1 2", "8 2", "20", "1",
 ],
 [ 
-"1 7", "7 7", "20", "1" 
+"1 7", "8 7", "20", "1" 
 ] ); 
 #OR: (["1 3", "30 4", "20", "1"],["1 3", "30 4", "20", "1"]); 
 # Here put the data this way: "starting-month_1 starting-day_1", "ending-month_1 ending-day_1", "start-up-period-duration_1", "time/steps-hour_1", "starting-month_2"starting-day_2", "ending-month_2 ending-day_2", "start-up-period-duration_2", "time/steps-hour_2", ..., "starting-month_n starting-day_n", "ending-month_n ending-day_n", "start-up-period-duration_n", "time/steps-hour_n"
@@ -72,7 +82,9 @@ $preventsim eq "y";
 [ 
 [ 
 "1 2 1", "7 2 24", "1" 
-], 
+]
+],
+[ 
 [ 
 "1 7 1", "7 7 24", "1" 
 ] 
@@ -118,64 +130,46 @@ $reportdata = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @retrie
 [ 
 [ 
 [ 
-{ 
-	1 => 
 	{
-		reporttitle => [ "feb01-feb07" ], #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "feb01-feb07", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
-		semaphorego => [ "" ], # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
-		semaphorestop => [ "" ], # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => [ "All" ] #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 	},
-	2 => 
 	{
-		reportititle => [ "feb01-feb07" ], #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "feb01-feb07", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
-		semaphorego => [ "" ], # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
-		semaphorestop => [ "" ], # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => [ "All" ] #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 	}
-}
-], 
+]
+],
+[ 
 [ 
-{ 
-	1 => 
 	{
-		reportititle => [ "jul01-jul07" ], #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "jul01-jul07", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
-		semaphorego => [ "" ], # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
-		semaphorestop => [ "" ], # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => [ "All" ] #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 	},
-	2 => 
 	{
-		reportititle => [ "jul01-jul07" ], #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "jul01-jul07", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
-		semaphorego => [ "" ], # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
-		semaphorestop => [ "" ], # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => [ "All" ] #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
-	},
-#	3 => 
-#	{
-#		reportititle => [ "feb01-feb07", "jul01-jul07" ], #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
-#		themereport => "temps", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
-#		semaphorego => [ "" ], # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
-#		semaphorestop => [ "" ], # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-#		textpattern => [ "Time", "AmbientdbTmp(degC)", "zonedbT(degC)", "zoneMRT(degC)", "zoneResT(degC)" ] #STRING IN THE RESULT FILE SIGNALLING WHAT COLUMNS HAS TO BE PICKED.
-#	},
-#	4 => 
-#	{
-#		reportititle => [ "feb01-feb07", "jul01-jul07" ], #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
-#		themereport => "comfort", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
-#		semaphorego => [ "" ], # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
-#		semaphorestop => [ "" ], # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-#		textpattern => [ "Time", "zonePMV(-)" ] #STRING IN THE RESULT FILE SIGNALLING WHAT COLUMNS HAS TO BE PICKED. 
-#	}
-}
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	}
 ] 
 ]
 ]; 
 
+#$vals{skipfile} = "skipfile.txt";
+#$vals{skipreport} = " ( ( $simtitle =~ /_1-2/ ) or ( $simtitle =~ /_2-2/ ) or ( $simtitle =~ /_3-2/ ) or ( $simtitle =~ /_4-2/ ) or ( $simtitle =~ /_5-2/ ) or ( $simtitle =~ /_6-2/ ) ) ";
+#$vals{skipreport} = " ( ( \$simtitle =~ /_1-2/ ) or ( \$simtitle =~ /_2-2/ ) or ( \$simtitle =~ /_3-2/ ) or ( \$simtitle =~ /_4-2/ ) or ( \$simtitle =~ /_5-2/ ) or ( \$simtitle =~ /_6-3/ ) or ( \$simtitle =~ /_6-5/ )) ";
+
 @keepcolumns = ( 
 [ "min res_temp", 2 ], [ "avg res_temp", 4 ], [ "max res_temp", 6 ], [ "radiation entering zone", 8 ], 
 [ "radiation transmitted through transparent surfaces", 9 ], [ "radiation absorbed by the zone", 10 ], 
@@ -212,28 +206,19 @@ $reportdata = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @retrie
 
 ######################### PARAMETER 1. #############################
 
-$vals{1}{applytype} = [ [ "obs_modification", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+$vals{1}{applytype} = [ [ "change_groundreflectance", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
-# "change_groundreflectance", "generic_changeandconstrain"
+# "change_groundreflectance", "generic_changeandconstrain", "vertex_translation"
 $vals{1}{general_variables} = 
 [
 "y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
-$vals{1}{obs_modify} = 
-[   
+$vals{1}{change_groundreflectance} =  
 [ 
-[ "e"  , "a", [ 0, .49, 0 ]  ], # IT MODIFIES THE ORIGIN OF OBSTRUCTION "h"
-[ "e"  , "b", [ 0, .49, 0 ]  ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
-]
+[ 0.65, [ 0.50, 0.80 ] ] # [ base value, [ low, high ] ]; OR: [ base value, half-range ];
 ];
-# [ 
-# what to modify? "a" for origin, "b" for dimensions, "c" for z_rotation, "d" for y_rotation, "g" for construction, "h" for opacity, "t" for transform	
-# enter value or values corresponding to the above. If origin coordinates of one extreme of the translation. 
-# If dimensions: x y z of dimensions. If rotation: swing of the rotation. If construction:construction name. If opacity: percentage of opacity.
-# if origin: base x y z origin. If dimensions: base x y z dimensions. If rotations: start rotation. If opacity: base opacity. if transform: "a" for rotation, "b" for transform.
-# ]
 
 
 ######################### PARAMETER 2. #############################
@@ -250,10 +235,12 @@ $vals{2}{general_variables} =
 $vals{2}{obs_modify} = 
 [   
 [ 
-[ "f"  , "a", [ 0, .49, 0 ]  ], # IT MODIFIES THE ORIGIN OF OBSTRUCTION "h"
-[ "f"  , "b", [ 0, .49, 0 ]  ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
+"/zones/box.geo", # GEO FILE IN WHICH THE OBSTRUCTIION
+[ "f"  , "a", [ [ 0, -0.02, 0 ], [ 0, -1.51, 0 ] ] ], # IT MODIFIES THE ORIGIN OF OBSTRUCTION "h"
+[ "f"  , "b", [ [ 0, 0.01, 0 ], [ 0, 1.50, 0 ] ] ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
 ]
 ];
+#$vals{2}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
 # [ 
 # what to modify? "a" for origin, "b" for dimensions, "c" for z_rotation, "d" for y_rotation, "g" for construction, "h" for opacity, "t" for transform	
 # enter value or values corresponding to the above. If origin coordinates of one extreme of the translation. 
@@ -276,10 +263,12 @@ $vals{3}{general_variables} =
 $vals{3}{obs_modify} = 
 [   
 [ 
-[ "g"  , "a", [ 0, .49, 0 ]  ], # IT MODIFIES THE ORIGIN OF OBSTRUCTION "h"
-[ "g"  , "b", [ 0, .49, 0 ]  ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
+"/zones/box.geo",
+[ "g"  , "a", [ [ 0, -0.02, 0 ], [ 0, -1.51, 0 ] ] ], # IT MODIFIES THE ORIGIN OF OBSTRUCTION "h"
+[ "g"  , "b", [ [ 0, 0.01, 0 ], [ 0, 1.50, 0 ] ] ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
 ]
 ];
+#$vals{3}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
 # [ 
 # what to modify? "a" for origin, "b" for dimensions, "c" for z_rotation, "d" for y_rotation, "g" for construction, "h" for opacity, "t" for transform	
 # enter value or values corresponding to the above. If origin coordinates of one extreme of the translation. 
@@ -287,6 +276,7 @@ $vals{3}{obs_modify} =
 # if origin: base x y z origin. If dimensions: base x y z dimensions. If rotations: start rotation. If opacity: base opacity. if transform: "a" for rotation, "b" for transform.
 # ]
 
+
 ######################### PARAMETER 4. #############################
 
 $vals{4}{applytype} = [ [ "obs_modification", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
@@ -295,16 +285,18 @@ $vals{4}{applytype} = [ [ "obs_modification", "boxform.cfg", "boxform.cfg", "a"
 # "change_groundreflectance", "generic_changeandconstrain"
 $vals{4}{general_variables} = 
 [
-"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
+"n", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
 $vals{4}{obs_modify} = 
 [   
-[ "/zones/box.geo",
-[ "h"  , "a", [ 0, .49, 0 ]  ], # IT MODIFIES THE ORIGIN OF OBSTRUCTION "h"
-[ "h"  , "b", [ 0, .49, 0 ]  ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
+[ 
+"/zones/box.geo",
+[ "h"  , "a", [ [ 0, -0.02, 0 ], [ 0, -1.51, 0 ] ] ], # IT MODIFIES THE ORIGIN OF OBSTRUCTION "h"
+[ "h"  , "b", [ [ 0, 0.01, 0 ], [ 0, 1.50, 0 ] ] ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
 ]
 ];
+#$vals{4}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
 # [ 
 # what to modify? "a" for origin, "b" for dimensions, "c" for z_rotation, "d" for y_rotation, "g" for construction, "h" for opacity, "t" for transform	
 # enter value or values corresponding to the above. If origin coordinates of one extreme of the translation. 
@@ -312,6 +304,7 @@ $vals{4}{obs_modify} =
 # if origin: base x y z origin. If dimensions: base x y z dimensions. If rotations: start rotation. If opacity: base opacity. if transform: "a" for rotation, "b" for transform.
 # ]
 
+
 ######################### PARAMETER 5. #############################
 
 $vals{5}{applytype} = [ [ "obs_modification", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
@@ -325,20 +318,21 @@ $vals{5}{general_variables} =
 ];
 $vals{5}{obs_modify} = 
 [   
-[ "/zones/box.geo",
-[ "i"  , "b", [ 0, 0, 1.49 ]  ], # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
+[ 
+"/zones/box.geo",
+[ "i"  , "b", [ [ 0, 0, 0 ], [ 0, 0, 3 ] ] ] # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
 ]
 ];
+#$vals{5}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
 # [ 
 # what to modify? "a" for origin, "b" for dimensions, "c" for z_rotation, "d" for y_rotation, "g" for construction, "h" for opacity, "t" for transform	
 # enter value or values corresponding to the above. If origin coordinates of one extreme of the translation. 
 # If dimensions: x y z of dimensions. If rotation: swing of the rotation. If construction:construction name. If opacity: percentage of opacity.
 # if origin: base x y z origin. If dimensions: base x y z dimensions. If rotations: start rotation. If opacity: base opacity. if transform: "a" for rotation, "b" for transform.
-# ]
+
 
 ######################### PARAMETER 6. #############################
 
-#$varinumbers{6} = 9; # THIS VALUE SPECIFIES A NUMBER OF STEPS FOR THIS PARAMETER, WHICH OVERRIDES THE VALUE IN @varinumbers.
 $vals{6}{applytype} = [ [ "rotation", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
@@ -352,14 +346,22 @@ $vals{6}{rotate} =
 [ 
 [ "y", "180", "c", "a" ],
 ];
+#$vals{6}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
+#$vals{6}{skipop} = [ [ " ( ( $to =~ /_6-5/ ) ) " ] ];
 # [ # rotate obstructions? "y" o "n", # swing of rotation (HALF SWING, SWING MEASURED ON ONE SIDE WITH REGARDS TO THE MIDDLE) 
 # update radiation calculation with the "ish" module?  "b" for yes and "c" for no, continue, # vertex around which to rotate ]
 ##### @applytype111 = (["rotation", "file_name", "target_file_name", "zone_letter"]);
-
-$vals{6}{recalculateish} = "y"; 
+$vals{6}{recalculateish} = [["y"]]; 
 ## recalculate the solar radiation? "y" or "n". This way the "ish" module is launched just at the end of a whole morphing operation, and not at every sub-operations composing it.
-
-
+$vals{6}{export_toenergyplus} = [ [ "y", "sim", "retrieve", "milan.epw", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], 
+[ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "2, 1,   !- Begin Month" ], 
+[ "12,31,   !- End Month", " 2, 7,   !- End Month" ] ] ];
+$vals{6}{use_modish} = 
+[
+[
+[ 1, "/zones/box.shd", 7 ]
+]
+]; 
 
 ######################### PARAMETER 7. #############################
 
@@ -612,8 +614,9 @@ $vals{111}{construction_reassignment} =
  ##### @applytype111 = (["construction_reassignment", "file_name", "target_file_name", "zone_letter"]);
  
  
-$vals{111}{thickness_change} = 
-[ ["n", 
+$vals{111}{change_thickness} = 
+[ 
+[
 [ a, b, c ], 
 [ [i, j], [a, b], [k] ], 
 [ [ [10, 20] , [20, 50] ], [ [20, 60] , [10, 40] ], [ [20, 50 ] ] ],
@@ -1071,7 +1074,7 @@ $vals{111}{propagate_constraints} = [
 ## THE VARIABLE AT THE CURRENT SEARCH STEP CAN BE NAMED WITHOUT THE NUMBER. EXAMPLE: $recalculateish, $translate, ETC.
 
 
-$vals{111}{recalculateish} = "n"; 
+$vals{111}{recalculateish} = [ [ "n" ] ];
 ## recalculate the solar radiation? "y" or "n". This way the "ish" module is launched just at the end of a whole morphing operation, and not at every sub-operations composing it.
 
 $vals{111}{use_modish} = 
@@ -1090,8 +1093,8 @@ $vals{111}{use_modish} =
 #]; 
 
 
-$vals{111}{export_toenergyplus} = "y"; 
-## THE CHOICE HERE IS BETWEEN "y", YES, AND EVERYTHING ELSE: LIKE NOTHING, OR "", OR "n", MEANING NO.
+## THE CHOICE HERE IS BETWEEN "y", YES, AND EVERYTHING ELSE: LIKE NOTHING, OR "", OR "n", MEANING NO. THE OTHER VALUES BETWEEN BRACKETS ARE: [ word_to_substitute, substituting_word]
+## SO: $vals{1}{export_toenergyplus} = [ [ "y", [ "word1_to_substitute", "substituting_word1]" ], [ "word2_to_substitute", "substituting_word2]" ], ... ] ];
 
 
 $vals{111}{generic_changeandconstrain} = 
@@ -1132,15 +1135,95 @@ $vals{111}{daylightcalc} = [   ##### THIS VARIABLE GOVERNS A FUNCTION WHICH LAUN
 "cell_Day_fa.df" # name of daylight factor file
 ]; #
 
-$vals{111}{skip} = 
+$vals{111}{skipop} = 
+[
 [ 
-" if ( ( $translate->[$counterzone][2][0] > 2 ) or ( $translate_>[$counterzone][2][0] < 8 ) ) "
+" ( ( \$translate->[\$counterzone][2][0] > 2 ) or ( \$translate_>[\$counterzone][2][0] < 8 ) ) "
 , 
-" if ( ( $translate->[$counterzone][2][0] > 2 ) or ( $translate_>[$counterzone][2][0] < 8 ) ) " 
+" ( ( \$translate->[\$counterzone][2][0] > 2 ) or ( \$translate_>[\$counterzone][2][0] < 8 ) ) " 
+]
 ]; 
 # THIS IS AN EXAMPLE OF CONDITION TO SKIP SOME TESTS, WRITTEN IN PERL.
 # IT WILL BE EVALED BY THE PROGRAM TO SKIP AN INSTANCE IF THE SPECIFIED CONDITION IS MET.
 
+$vals{111}{pin_obstructions} = 
+[ 
+[ "/zones/box.geo", #file name of the geo file
+1, 2, 3 # obstruction number
+]
+]; 
+
+$vals{111}{export_toenergyplus} = [ [ "y", "sim", "retrieve", "milan.epw", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], 
+[ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "2, 1,   !- Begin Month" ], 
+[ "12,31,   !- End Month", " 2, 7,   !- End Month" ] ] ];
+
+$vals{111}{use_modish} = 
+[
+[
+[ 1, "/zones/box.shd", 7 ]
+]
+]; 
+
+
+$vals{112}{translate_surface} =  
+[ 
+[ "b", [ "b", "d" ], [  1, 1  ] , "c", [ [ -4, -5, -6], [ 4, 5, 6] ] ],
+];
+# transform type: "a" for surface translation along normal, "b" for x y z surface translation.
+# [ # surfaces to be translated (letters) ]
+# [ # end movements, in case of surface translation along_normal (example: [2, 2, 2, 2, 2, 2] ), or "x y z" translation, in the case of x y z translation of surface (example: ["2  2  2", "2  2  2"]). Relative to the fields above.
+# update radiation? "b" for yes or "c" for no.
+#### @applytype111 = ( ["surface_translation", "file_name", "target_file_name", "zone_letter"]); 
+
+$vals{112}{translate} =  
+[ 
+[ "n", [ ["-9", "0", "0"], ["9", "0", "0"] ], "c", ],
+];
+
+$vals{112}{rotate_surface} = 
+[ 
+[   [ "b", "d" ], [ 10, 12 ], [ [ -30, 30 ], [ -30, 30]  ] , [ "y", "y" ]   ]
+];
+# [
+# [ # surfaces to rotate ]
+# [ vertices around which to rotate ]
+# [ wing extremes of the rotation ] # THAT IS: HALF RANGE OF THE ROTATION. 
+# [ apply to others? "y" or "n" ]
+##### @applytype111 = [ ["surface_rotation", "file_name", "target_file_name", "zone_letter"]);
+
+$vals{112}{rotate} = 
+[ 
+[ "y", [ -180, 180 ], "c", "a" ],
+];
+
+$vals{112}{translate_vertices} = 
+[ 
+[ 
+[ "a", "b", ],  
+[ [[0, -0.5, 0], [0, 0.5, 0]], [[0, -0.3, 0], [0, 0.3, 0]] ], 
+[ "/zones/zone.geo" ], # source file
+[ "n" ] # long menus?
+]
+];
+# [ @vertexes_to_transl, Consider that after "p" you have to write "0\nq" ]
+# [ [ x y z movs ] ],  in case of surface x y z translation
+# source file, # long menus?
+
+$vals{112}{shift_vertices} = 
+[ 
+[ "j", [ "i" , "l" , "m" ], [ [ -0.8, 0.8 ], [ -0.4, 0.4 ],[ -0.3, 0.3 ] ], "c", ],
+];
+# [
+# movement type: "j": shift vertices along a line. "h": align vertices with a line.
+# [ pairs of vertices defining axes ]
+# [ Complete shift movements - whole excursion ]
+# configuration file for conditions
+# ]
+#### @applytype111 = ( ["vertices_shift", "file_name", "target_file_name", "zone_letter"]);
+
+
+
+
 #############################################################################################
 
 
